@@ -198,6 +198,8 @@ class Community:
         verbose=False,
         scaler="std",
         pooling="fixed",
+        temporal_index="year",
+        unit_index="geoid",
         **kwargs,
     ):
         """Create a geodemographic typology by running a cluster analysis on the study area's neighborhood attributes.
@@ -215,6 +217,13 @@ class Community:
             subset of columns on which to apply the clustering
         verbose : bool, optional
             whether to print warning messages (the default is False).
+        temporal_index : str
+            which column on the dataframe defines time and or sequencing of the
+            long-form data. Default is "year"
+        unit_index : str
+            which column on the long-form dataframe identifies the stable units
+            over time. In a wide-form dataset, this would be the unique index.
+            Default is "geoid"
         scaler : None or scaler from sklearn.preprocessing, optional
             a scikit-learn preprocessing class that will be used to rescale the
             data. Defaults to sklearn.preprocessing.StandardScaler
@@ -242,6 +251,8 @@ class Community:
             verbose=verbose,
             scaler=scaler,
             pooling=pooling,
+            temporal_index=temporal_index,
+            unit_index=unit_index,
             **kwargs,
         )
 
@@ -261,8 +272,10 @@ class Community:
         columns=None,
         threshold_variable="count",
         threshold=10,
+        unit_index="geoid",
+        temporal_index='year',
+        scaler="std",
         return_model=False,
-        scaler=None,
         weights_kwargs=None,
         **kwargs,
     ):
@@ -289,6 +302,13 @@ class Community:
             been aggregated
         threshold : numeric, optional
             threshold to use for max-p clustering (the default is 10).
+        temporal_index : str
+            which column on the dataframe defines time and or sequencing of the
+            long-form data. Default is "year"
+        unit_index : str
+            which column on the long-form dataframe identifies the stable units
+            over time. In a wide-form dataset, this would be the unique index.
+            Default is "geoid"
         scaler : None or scaler from sklearn.preprocessing, optional
             a scikit-learn preprocessing class that will be used to rescale the
             data. Defaults to sklearn.preprocessing.StandardScaler
@@ -315,6 +335,8 @@ class Community:
             return_model=return_model,
             scaler=scaler,
             weights_kwargs=weights_kwargs,
+            unit_index=unit_index,
+            temporal_index=temporal_index,
             **kwargs,
         )
 
@@ -330,24 +352,38 @@ class Community:
         cluster_col=None,
         w_type="queen",
         w_options=None,
+        temporal_index="year",
+        unit_index="geoid",
+        permutations=0,
         figsize=(13, 12),
         n_rows=3,
         n_cols=3,
         suptitle=None,
+        title_kwds=None,
         savefig=None,
         dpi=300,
-        **kwargs,
     ):
-        """Plot global and spatially-conditioned transition matrices as heatmaps
+        """Plot global and spatially-conditioned transition matrices as heatmaps.
 
         Parameters
         ----------
         cluster_col : str
             column on the Community.gdf containing neighborhood type labels
-        w_type : str {'queen', 'rook'}
-            which type of libpysal spatial weights objects to encode connectivity
+        temporal_index : string, optional
+            Column defining time and or sequencing of the long-form data.
+            Default is "year".
+        unit_index : string, optional
+            Column identifying the unique id of spatial units.
+            Default is "geoid".
+        w_type : string, optional
+            Type of spatial weights type ("rook", "queen", "knn" or
+            "kernel") to be used for spatial structure. Default is
+            None, if non-spatial Markov transition rates are desired.
         w_options : dict
             additional options passed to a libpysal weights constructor (e.g. `k` for a KNN weights matrix)
+        permutations : int, optional
+            number of permutations for use in randomization based
+            inference (the default is 0).
         figsize : tuple, optional
             size of the resulting figure (13, 12)
         n_rows : int, optional
@@ -373,13 +409,16 @@ class Community:
             cluster_col=cluster_col,
             w_type=w_type,
             w_options=w_options,
+            temporal_index=temporal_index,
+            unit_index=unit_index,
+            permutations=permutations,
             figsize=figsize,
             n_rows=n_rows,
             n_cols=n_cols,
             suptitle=suptitle,
+            title_kwds=title_kwds,
             savefig=savefig,
             dpi=dpi,
-            **kwargs,
         )
         return ax
 
@@ -466,8 +505,8 @@ class Community:
         cmap="bwr",
         title="",
         dpi=500,
-        time_var="year",
-        id_var="geoid",
+        temporal_index="year",
+        unit_index="geoid",
         **kwargs,
     ):
         """Plot of the silhouette scores of a Community model.
@@ -498,10 +537,10 @@ class Community:
         dpi        : int, optional
                      dpi of the saved image if save_fig=True
                     default is 500
-        time_var   : string, optional
+        temporal_index   : string, optional
                      the column in the community gdf that identifies time period
                      default is 'year' from US census data
-        id_var     : string, optional
+        unit_index     : string, optional
                      column in gdf that identifies geographic units
                      default is 'geoid' from US census data
         kwargs     : **kwargs, optional
@@ -528,7 +567,9 @@ class Community:
                 df = df.to_crs(epsg=3857)
         if not year:
             ax[0].hist(self.models[model_name].silhouettes["silhouettes"])
-            df.join(self.models[model_name].silhouettes, on=[id_var, time_var]).plot(
+            df.join(
+                self.models[model_name].silhouettes, on=[unit_index, temporal_index]
+            ).plot(
                 "silhouettes",
                 ax=ax[1],
                 alpha=alpha,
@@ -543,7 +584,8 @@ class Community:
         else:
             ax[0].hist(self.models[model_name][year].silhouettes["silhouettes"])
             df[df.year == year].join(
-                self.models[model_name][year].silhouettes, on=[id_var, time_var]
+                self.models[model_name][year].silhouettes,
+                on=[unit_index, temporal_index],
             ).plot(
                 "silhouettes",
                 ax=ax[1],
@@ -576,8 +618,8 @@ class Community:
         title="",
         alpha=0.5,
         dpi=500,
-        time_var="year",
-        id_var="geoid",
+        temporal_index="year",
+        unit_index="geoid",
         **kwargs,
     ):
         """Plot the nearest_labels of the community model.
@@ -605,10 +647,10 @@ class Community:
         dpi        : int, optional
                      dpi of the saved image if save_fig=True
                      default is 500
-        time_var   : string, optional
+        temporal_index   : string, optional
                      the column in the community gdf that identifies time period
                      default is 'year' from US census data
-        id_var     : string, optional
+        unit_index     : string, optional
                      column in gdf that identifies geographic units
                      default is 'geoid' from US census data
         kwargs     : **kwargs, optional
@@ -640,7 +682,7 @@ class Community:
                 df = df.to_crs(epsg=3857)
         if not year:
             temp_df = df.join(
-                self.models[model_name].nearest_labels, on=[id_var, time_var]
+                self.models[model_name].nearest_labels, on=[unit_index, temporal_index]
             )
             temp_df = temp_df[["nearest_label", "geometry", model_name]]
             temp_df.set_index(model_name, inplace=True)
@@ -658,9 +700,10 @@ class Community:
                 ctx.add_basemap(ax[1], source=ctxmap)
         else:
             temp_df = df.join(
-                self.models[model_name][year].nearest_labels, on=[id_var, time_var]
+                self.models[model_name][year].nearest_labels,
+                on=[unit_index, temporal_index],
             )
-            temp_df = temp_df[["nearest_label", time_var, "geometry", model_name]]
+            temp_df = temp_df[["nearest_label", temporal_index, "geometry", model_name]]
             temp_df.set_index(model_name, inplace=True)
             df[df.year == year].plot(
                 model_name, ax=ax[0], alpha=alpha, legend=True, categorical=True
@@ -697,8 +740,8 @@ class Community:
         alpha=0.5,
         cmap="bwr",
         dpi=500,
-        time_var="year",
-        id_var="geoid",
+        temporal_index="year",
+        unit_index="geoid",
         **kwargs,
     ):
         """Plot the path_silhouettes of Commmunity model.
@@ -729,10 +772,10 @@ class Community:
         dpi : int, optional
             dpi of the saved image if save_fig=True
             default is 500
-        time_var : string, optional
+        temporal_index : string, optional
             the column in the community gdf that identifies time period
             default is 'year' from US census data
-        id_var : string, optional
+        unit_index : string, optional
             column in gdf that identifies geographic units
             default is 'geoid' from US census data
         kwargs : **kwargs, optional
@@ -755,7 +798,8 @@ class Community:
         if not year:
             ax[0].hist(self.models[model_name].path_silhouettes["path_silhouettes"])
             self.gdf.join(
-                self.models[model_name][year].path_silhouettes, on=[id_var, time_var]
+                self.models[model_name][year].path_silhouettes,
+                on=[unit_index, temporal_index],
             ).plot(
                 "path_silhouettes",
                 ax=ax[1],
@@ -773,7 +817,8 @@ class Community:
                 self.models[model_name][year].path_silhouettes["path_silhouettes"]
             )
             self.gdf[self.gdf.year == year].join(
-                self.models[model_name][year].path_silhouettes, on=[id_var, time_var]
+                self.models[model_name][year].path_silhouettes,
+                on=[unit_index, temporal_index],
             ).plot(
                 "path_silhouettes",
                 ax=ax[1],
@@ -806,8 +851,8 @@ class Community:
         alpha=0.5,
         cmap="bwr",
         dpi=500,
-        time_var="year",
-        id_var="geoid",
+        temporal_index="year",
+        unit_index="geoid",
         **kwargs,
     ):
         """Plot boundary_silhouettes of the Commiunity model.
@@ -838,10 +883,10 @@ class Community:
         dpi        : int, optional
                      dpi of the saved image if save_fig=True
                      default is 500
-        time_var   : string, optional
+        temporal_index   : string, optional
                      the column in the community gdf that identifies time period
                      default is 'year' from US census data
-        id_var     : string, optional
+        unit_index     : string, optional
                      column in gdf that identifies geographic units
                      default is 'geoid' from US census data
         kwargs     : **kwargs, optional
@@ -871,7 +916,7 @@ class Community:
             )
             self.gdf.join(
                 self.models[model_name][year].boundary_silhouettes,
-                on=[id_var, time_var],
+                on=[unit_index, temporal_index],
             ).plot(
                 "boundary_silhouettes",
                 ax=ax[1],
@@ -897,7 +942,7 @@ class Community:
             )
             self.gdf[self.gdf.year == year].join(
                 self.models[model_name][year].boundary_silhouettes,
-                on=[id_var, time_var],
+                on=[unit_index, temporal_index],
             ).plot(
                 "boundary_silhouettes",
                 ax=ax[1],
@@ -1056,7 +1101,6 @@ class Community:
                             legend=legend,
                             legend_kwds=legend_kwds,
                             alpha=alpha,
-
                         )
                     else:
                         df[df.year == year].plot(
@@ -1069,7 +1113,6 @@ class Community:
                             legend=legend,
                             legend_kwds=legend_kwds,
                             alpha=alpha,
-
                         )
                 if ctxmap:  # need set basemap of each graph
                     ctx.add_basemap(axs[i], source=ctxmap)
@@ -1091,7 +1134,6 @@ class Community:
                         legend=legend,
                         legend_kwds=legend_kwds,
                         alpha=alpha,
-
                     )
                 else:
                     df[df.year == year].plot(
@@ -1124,7 +1166,7 @@ class Community:
         column=None,
         filename=None,
         title="",
-        time_col="year",
+        temporal_index="year",
         time_periods=None,
         scheme="quantiles",
         k=5,
@@ -1151,7 +1193,7 @@ class Community:
                         output file name
         title        : str, optional
                        desired title of figure
-        time_col     : str, required
+        temporal_index     : str, required
                         column on the Community.gdf that stores time periods
         time_periods:  list, optional
                         subset of time periods to include in the animation. If None, then all times will be used
@@ -1192,14 +1234,14 @@ class Community:
         if not gdf.crs == 3857:
             gdf = gdf.to_crs(3857)
         if not time_periods:
-            time_periods = list(gdf[time_col].unique())
+            time_periods = list(gdf[temporal_index].unique())
         time_periods = sorted(time_periods)
         with tempfile.TemporaryDirectory() as tmpdirname:
             for i, time in enumerate(time_periods):
                 fig, ax = plt.subplots(figsize=figsize)
                 outpath = PurePath(tmpdirname, f"file_{i}.png")
                 if categorical:
-                    gdf[gdf[time_col] == time].plot(
+                    gdf[gdf[temporal_index] == time].plot(
                         column,
                         categorical=True,
                         ax=ax,
@@ -1209,7 +1251,7 @@ class Community:
                     )
                 else:
                     classifier = schemes[scheme](gdf[column].dropna().values, k=k)
-                    gdf[gdf[time_col] == time].plot(
+                    gdf[gdf[temporal_index] == time].plot(
                         column,
                         scheme="user_defined",
                         classification_kwds={"bins": classifier.bins},
@@ -1237,7 +1279,13 @@ class Community:
             )
 
     def transition(
-        self, cluster_col, time_var="year", id_var="geoid", w_type=None, permutations=0
+        self,
+        cluster_col,
+        temporal_index="year",
+        unit_index="geoid",
+        w_type=None,
+        w_options=None,
+        permutations=0,
     ):
         """
         (Spatial) Markov approach to transitional dynamics of neighborhoods.
@@ -1248,38 +1296,45 @@ class Community:
 
         Parameters
         ----------
-        cluster_col     : string or int
-                          Column name for the neighborhood segmentation, such as
-                          "ward", "kmeans", etc.
-        time_var        : string, optional
-                          Column defining time and or sequencing of the long-form data.
-                          Default is "year".
-        id_var          : string, optional
-                          Column identifying the unique id of spatial units.
-                          Default is "geoid".
-        w_type          : string, optional
-                          Type of spatial weights type ("rook", "queen", "knn" or
-                          "kernel") to be used for spatial structure. Default is
-                          None, if non-spatial Markov transition rates are desired.
-        permutations    : int, optional
-                          number of permutations for use in randomization based
-                          inference (the default is 0).
-
+        cluster_col : string or int
+            Column name for the neighborhood segmentation, such as
+            "ward", "kmeans", etc.
+        temporal_index : string, optional
+            Column defining time and or sequencing of the long-form data.
+            Default is "year".
+        unit_index : string, optional
+            Column identifying the unique id of spatial units.
+            Default is "geoid".
+        w_type : string, optional
+            Type of spatial weights type ("rook", "queen", "knn" or
+            "kernel") to be used for spatial structure. Default is
+            None, if non-spatial Markov transition rates are desired.
+        w_options : dict
+            additional options passed to a libpysal weights constructor (e.g. `k` for a KNN weights matrix)
+        permutations : int, optional
+            number of permutations for use in randomization based
+            inference (the default is 0).
 
         Returns
         ---------
-        mar             : giddy.markov.Markov or giddy.markov.Spatial_Markov
-                          if w_type=None, return a classic Markov instance;
-                          if w_type is given, return a Spatial_Markov instance
+        mar : giddy.markov.Markov or giddy.markov.Spatial_Markov
+            if w_type=None, return a classic Markov instance;
+            if w_type is given, return a Spatial_Markov instance
 
         """
+        assert unit_index in self.gdf.columns.to_list(), (
+            f"unit_index: {unit_index} is not in the columns."
+            " Please use an appropriate index that properly identifies spatial units."
+        )
+
         mar = _transition(
             self.gdf,
             cluster_col,
-            time_var=time_var,
-            id_var=id_var,
+            temporal_index=temporal_index,
+            unit_index=unit_index,
             w_type=w_type,
             permutations=permutations,
+            w_options=w_options,
         )
         return mar
 
@@ -1290,8 +1345,8 @@ class Community:
         subs_mat=None,
         dist_type=None,
         indel=None,
-        time_var="year",
-        id_var="geoid",
+        temporal_index="year",
+        unit_index="geoid",
     ):
         """
         Pairwise sequence analysis to evaluate the distance/dissimilarity
@@ -1326,10 +1381,10 @@ class Community:
                           transitions. Based on :cite:`Biemann:2011`.
         indel           : float, optional
                           insertion/deletion cost.
-        time_var        : string, optional
+        temporal_index   : string, optional
                           Column defining time and or sequencing of the long-form data.
                           Default is "year".
-        id_var          : string, optional
+        unit_index       : string, optional
                           Column identifying the unique id of spatial units.
                           Default is "geoid".
 
@@ -1354,8 +1409,8 @@ class Community:
             subs_mat=subs_mat,
             dist_type=dist_type,
             indel=indel,
-            time_var=time_var,
-            id_var=id_var,
+            temporal_index=temporal_index,
+            unit_index=unit_index,
         )
         gdf_new = Community(gdf_temp)
         return gdf_new, df_wide, seq_dis_mat
@@ -1363,14 +1418,14 @@ class Community:
     def simulate(
         self,
         model_name=None,
-        index_col="geoid",
+        unit_index="geoid",
         w_type="queen",
         w_options=None,
         base_year=2010,
         new_colname="predicted",
         increment=10,
         time_steps=3,
-        time_col="year",
+        temporal_index="year",
         seed=None,
     ):
         """Simulate community dynamics using spatial Markov transition rules.
@@ -1379,7 +1434,7 @@ class Community:
         ----------
         model_name : [type], optional
             [description], by default None
-        index_col : str, optional
+        unit_index : str, optional
             column on the community gdf that denotes the unique index of geographic units
             for U.S. census data this is "geoid" (which is the default)
         w_type : str {'queen', 'rook'}
@@ -1395,7 +1450,7 @@ class Community:
             number of units in each time step (e.g. for a model based on decennial census data, this is 10)
         time_steps : int, optional
             number of time periods to simulate
-        time_col : str, optional
+        temporal_index : str, optional
             column on the community gdf that denotes the time index. For builtin data, this is "year"
         seed: int, optional
             seed passed to numpy random number generator
@@ -1415,10 +1470,10 @@ class Community:
                 w_options=w_options,
                 base_year=base_year,
                 new_colname=new_colname,
-                index_col=index_col,
+                unit_index=unit_index,
                 increment=increment,
                 time_steps=time_steps,
-                time_col=time_col,
+                temporal_index=temporal_index,
                 seed=seed,
             )
             return gdf
@@ -1430,10 +1485,10 @@ class Community:
                 w_options=w_options,
                 base_year=base_year,
                 new_colname=new_colname,
-                index_col=index_col,
+                unit_index=unit_index,
                 increment=increment,
                 time_steps=time_steps,
-                time_col=time_col,
+                temporal_index=temporal_index,
                 seed=seed,
             )
             gdfs = pd.concat(gdfs)
@@ -1692,14 +1747,14 @@ class Community:
             states = None
 
         df_dict = {
-            1990: datasets.tracts_1990(states=states),
-            2000: datasets.tracts_2000(states=states),
-            2010: datasets.tracts_2010(states=states),
+            1990: datasets.tracts_1990,
+            2000: datasets.tracts_2000,
+            2010: datasets.tracts_2010,
         }
 
         tracts = []
         for year in years:
-            tracts.append(df_dict[year])
+            tracts.append(df_dict[year](states=states))
         tracts = pd.concat(tracts, sort=False)
 
         if isinstance(boundary, gpd.GeoDataFrame):
@@ -1915,5 +1970,12 @@ class Community:
             neighborhood units over time.
 
         """
+        crss = set([gdf.crs for gdf in gdfs])
+        assert len(crss) == 1, (
+            f"These geodataframes have {len(crss)} different CRS: "
+            f"{[i.to_string() for i in crss]}."
+            " To continue, reproject the geodataframes into a single consistent system."
+            " See: https://geopandas.org/projections.html for more inforamtion."
+        )
         gdf = pd.concat(gdfs, sort=True)
         return cls(gdf=gdf)
